@@ -49,7 +49,7 @@ class TrainerBase:
         if self.trainer_mode == 'start':
             if len(os.listdir(self.checkpoint_dir)) > 0:
                 raise Exception('Error! Output checkpoint dir (%s) not empty, which is incompatible with "%s" trainer mode'
-                                % (self.cfg['checkpoint_dir'], self.trainer_mode))
+                                % (self.checkpoint_dir, self.trainer_mode))
         elif self.trainer_mode == 'resume':
             if not len(os.listdir(self.checkpoint_dir)):
                 raise Exception('Error! Cannot resume from an empty checkpoint dir. Use "start" trainer mode instead')
@@ -97,12 +97,12 @@ class TrainerBase:
             self.cfg = json.load(fp)
 
     def get_last_checkpoint(self):
-        info_last_ckpt = os.path.join(self.cfg['checkpoint_dir'], 'last_checkpoint.txt')
+        info_last_ckpt = os.path.join(self.checkpoint_dir, 'last_checkpoint.txt')
         try:
             with open(info_last_ckpt, 'r') as fp:
                 last_checkpoint_name = fp.read().strip()
         except FileNotFoundError:
-            print('"last_checkpoint.txt" not found in checkpoint directory: %s' % self.cfg['checkpoint_dir'])
+            print('"last_checkpoint.txt" not found in checkpoint directory: %s' % self.checkpoint_dir)
             last_checkpoint_name = None
 
         return last_checkpoint_name
